Data directory
==============

This directory contains data files included with the package source
code distribution. Note that this is intended only for relatively small files
- large files should be externally hosted and downloaded as needed.

Also see https://github.com/spacetelescope/style-guides/blob/master/guides/where-to-put-your-data.md
for more information.
